"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findTermsInText = void 0;
const terms_1 = require("./terms");
function findTermsInText(text, options) {
    var _a;
    const { maxHighlightExtension = 3 } = options !== null && options !== void 0 ? options : {};
    const result = [
        {
            text,
        },
    ];
    const termsByLengthDesc = Array.from(terms_1.terms.values()).sort((a, b) => b.name.length - a.name.length);
    for (const { name: term, definition, frontmatter } of termsByLengthDesc) {
        for (const textChunk of result) {
            if (textChunk.term) {
                continue;
            }
            // does the term appear in the text?
            const index = textChunk.text.toLowerCase().indexOf(term.toLowerCase());
            if (index === -1) {
                continue;
            }
            // does the term appear in a context to avoid?
            if ("surroundingContextsToAvoid" in frontmatter &&
                Array.isArray(frontmatter.surroundingContextsToAvoid)) {
                const surroundingContextsToAvoid = frontmatter.surroundingContextsToAvoid;
                const surroundingContext = result.map((r) => r.text).join(" ").toLocaleLowerCase();
                if (surroundingContextsToAvoid.some((context) => surroundingContext.includes(context.toLocaleLowerCase()))) {
                    continue;
                }
            }
            // extend the highlight to include surrounding letters up to maxHighlightExtension
            let endIndexOfTerm = index + term.length;
            for (let i = 0; i < maxHighlightExtension; i++) {
                // if the end of the text is reached, stop
                if (/\s/.test((_a = textChunk.text[endIndexOfTerm]) !== null && _a !== void 0 ? _a : " ")) {
                    break;
                }
                endIndexOfTerm++;
            }
            // if the highlight ends with another character and is not the end of the line, reset back to just the term
            if (endIndexOfTerm < textChunk.text.length &&
                /\S/.test(textChunk.text[endIndexOfTerm])) {
                endIndexOfTerm = index + term.length;
            }
            const before = [{ text: textChunk.text.slice(0, index) }];
            const after = [{ text: textChunk.text.slice(endIndexOfTerm) }];
            if (index === 0) {
                before.pop();
            }
            if (endIndexOfTerm === textChunk.text.length) {
                after.pop();
            }
            result.splice(result.indexOf(textChunk), 1, ...before, {
                text: textChunk.text.slice(index, endIndexOfTerm),
                term: {
                    name: term,
                    definition,
                    frontmatter,
                },
            }, ...after);
        }
    }
    return result;
}
exports.findTermsInText = findTermsInText;
//# sourceMappingURL=search.js.map